@@ -1,20 +1,19 @@
 """Asynchronous Python client for the IPX800 v5 API."""
 
-from .const import *
+
 from .counter import Counter
-from .exceptions import (
-    IPX800CannotConnectError,
-    IPX800InvalidAuthError,
-    IPX800RequestError,
-)
+from .exceptions import (IPX800CannotConnectError, IPX800InvalidAuthError,
+                         IPX800RequestError)
 from .ipx800 import IPX800
-from .ipx800_io import IPX800AnalogInput, IPX800DigitalInput, IPX800Relay
+from .ipx800_io import (IPX800AnalogInput, IPX800DigitalInput, IPX800OpenColl,
+                        IPX800OptoInput, IPX800Relay)
 from .tempo import Tempo
 from .thermostat import Thermostat
 from .x4fp import X4FP, X4FPMode
 from .x4vr import X4VR
 from .x8d import X8D
 from .x8r import X8R
+from .x010v import X010V
 from .x24d import X24D
 from .xdimmer import XDimmer
 from .xpwm import XPWM
@@ -28,9 +27,12 @@ __all__ = [
     "IPX800",
     "IPX800AnalogInput",
     "IPX800DigitalInput",
+    "IPX800OptoInput",
     "IPX800Relay",
+    "IPX800OpenColl",
     "Tempo",
     "Thermostat",
+    "X010V",
     "X4FP",
     "X4FPMode",
     "X4VR",
