@@ -6,7 +6,10 @@ from .ipx800 import IPX800
 
 
 class XDimmer(Extension):
+    """Represent an X-Dimmer light."""
+
     def __init__(self, ipx: IPX800, ext_number: int, output_number: int):
+        """Init the extension."""
         super().__init__(ipx, ext_type, ext_number, output_number)
         self.io_state_id = self._config["ioOn_id"][output_number - 1]
         self.io_command_id = self._config["ioOn_id"][output_number - 1]
